@@ -23,8 +23,12 @@ while (j <= np){
 
 graphics.off()
 ts.plot(y, ylim=c(0,max),xlim=c(0,numx),col="red", xlab=ABxlab, ylab=ABylab, main=ABmain )
-instruct<-"You can add lines between phases by using the ABlines() function. You can add text by using the ABtext() function. You can also add a mean, median, sd line by using the ABstat() function." 
-strwrap(instruct) 
+
 ab<-NULL
 ab<<-recordPlot()
+writeLines("-------------------------------------------------------------------------------------")
+writeLines("1-You can add lines between phases by using the ABlines() function.")
+writeLines("2-You can add text by using the ABtext() function.")
+writeLines("3-You can also add a mean, median, sd line by using the ABstat() function.")
+writeLines("-------------------------------------------------------------------------------------")
 }
